@@ -10,6 +10,16 @@ PPIx::Regexp - Represent a regular expression of some sort
  PPIx::Regexp::Dumper->new( $re )
      ->print();
 
+=head1 DEPRECATION NOTICE
+
+The C<postderef> argument to L<new()|/new> is retracted, and
+postfix dereferences are always be recognized.
+
+Starting with version 0.074_01, the first use of this argument warned.
+With version 0.079_01, all uses warned. With version 0.080_01,
+all uses became fatal. With version 0.084_01, all mention of this
+argument was removed, except for this notice.
+
 =head1 INHERITANCE
 
 C<PPIx::Regexp> is a L<PPIx::Regexp::Node|PPIx::Regexp::Node>.
@@ -55,14 +65,6 @@ for little tangible gain.
 
 =head1 NOTICE
 
-The use of this class to parse non-regexp quote-like strings was an
-experiment that I consider failed. Therefore this use is B<deprecated>
-in favor of L<PPIx::QuoteLike|PPIx::QuoteLike>. As of version 0.058_01,
-the first use of the C<parse> argument to L<new()|/new> resulted in a
-warning. As of version 0.062_01, all uses of the C<parse> argument
-resulted in a warning. As of version 0.068_01, the C<parse> argument
-will become fatal.
-
 The author will attempt to preserve the documented interface, but if the
 interface needs to change to correct some egregiously bad design or
 implementation decision, then it will change.  Any incompatible changes
@@ -91,7 +93,7 @@ Known examples of this include:
 
 =item C<$(> no longer interpolates as of Perl 5.005, per C<perl5005delta>.
 
-Newer Perls seem to parse this as C<qr{$}> (i.e. and end-of-string or
+Newer Perls seem to parse this as C<qr{$}> (i.e. an end-of-string or
 newline assertion) followed by an open parenthesis, and that is what
 C<PPIx::Regexp> does.
 
@@ -142,6 +144,17 @@ were introduced to deal with this complication.
 is parsed as the octal equivalent of C<\x{...}>. This is its meaning as
 of perl 5.13.2. Before 5.13.2 it was simply literal C<'o'> and so on.
 
+=item C<x{,3}>
+
+(with first count omitted) is allowed as a quantifier as of Perl 5.33.6.
+The previous parse made this all literals.
+
+=item C<x{ 0 , 3 }>
+
+(with spaces inside but adjacent to curly brackets, or around the comma
+if any) is allowed as a quantifier as of Perl 5.33.6. The previous parse
+made this all literals.
+
 =back
 
 There are very probably other examples of this. When they come to light
@@ -163,14 +176,26 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Node };
 
-use PPIx::Regexp::Constant qw{ @CARP_NOT };
+use Carp;
+use PPIx::Regexp::Constant qw{
+    ARRAY_REF
+    LOCATION_LINE
+    LOCATION_CHARACTER
+    LOCATION_COLUMN
+    LOCATION_LOGICAL_LINE
+    LOCATION_LOGICAL_FILE
+    @CARP_NOT
+};
 use PPIx::Regexp::Lexer ();
 use PPIx::Regexp::Token::Modifier ();	# For its modifier manipulations.
 use PPIx::Regexp::Tokenizer;
-use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
+use PPIx::Regexp::Util qw{
+    __choose_tokenizer_class
+    __instance
+};
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.069';
+our $VERSION = '0.087';
 
 =head2 new
 
@@ -226,26 +251,40 @@ string before it tokenizes it. For example:
      encoding => 'iso-8859-1',
  );
 
-=item parse parse_type
+=item index_locations Boolean
 
-This option specifies what kind of parse is to be done. Possible values
-are C<'regex'>, C<'string'>, or C<'guess'>. Any value but C<'regex'> is
-experimental.
+This Boolean option specifies whether the locations of the elements in
+the regular expression should be indexed.
 
-As it turns out, I consider parsing non-regexp quote-like things with
-this class to be a failed experiment, and the relevant functionality is
-being deprecated and removed in favor of
-L<PPIx::QuoteLike|PPIx::QuoteLike>. See above for details. As of version
-0.068_01, any use of this option throws an exception.
+If unspecified or specified as C<undef> a default value is used. This
+default is true if the argument is a L<PPI::Element|PPI::Element> or the
+C<location> option was specified. Otherwise the default is false.
 
-=item postderef boolean
+=item location array_reference
+
+This option specifies the location of the new object in the document
+from which it was created. It is a reference to a five-element array
+compatible with that returned by the C<location()> method of
+L<PPI::Element|PPI::Element>.
+
+If not specified, the location of the original string is used if it was
+specified as a L<PPI::Element|PPI::Element>.
+
+If no location can be determined, the various C<location()> methods will
+return C<undef>.
+
+=item postderef Boolean
+
+B<THIS ARGUMENT IS DEPRECATED>.
+See L<DEPRECATION NOTICE|/DEPRECATION NOTICE> above for the details.
 
 This option is passed on to the tokenizer, where it specifies whether
 postfix dereferences are recognized in interpolations and code. This
 experimental feature was introduced in Perl 5.19.5.
 
-The default is the value of
-C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF>, which is true. When
+As of version 0.074_01, the default is true.  Through release 0.074, the
+default was the value of
+C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF>, which was true. When
 originally introduced this was false, but was documented as becoming
 true when and if postfix dereferencing became mainstream. The  intent to
 mainstream was announced with Perl 5.23.1, and became official (so to
@@ -256,7 +295,7 @@ Note that if L<PPI|PPI> starts unconditionally recognizing postfix
 dereferences, this argument will immediately become ignored, and will be
 put through a deprecation cycle and removed.
 
-=item strict boolean
+=item strict Boolean
 
 This option is passed on to the tokenizer and lexer, where it specifies
 whether the parse should assume C<use re 'strict'> is in effect.
@@ -298,6 +337,11 @@ is it supported.
 	my ( $class, $content, %args ) = @_;
 	ref $class and $class = ref $class;
 
+	# We have to do this very early so the tokenizer can see it.
+	defined $args{index_locations}
+	    or $args{index_locations} = (
+	    !! $args{location} || __instance( $content, 'PPI::Element' ) );
+
 	$errstr = undef;
 
 	# As of 0.068_01 this either fails or returns
@@ -313,10 +357,20 @@ is it supported.
 	my $lexer = PPIx::Regexp::Lexer->new( $tokenizer, %args );
 	my @nodes = $lexer->lex();
 	my $self = $class->SUPER::__new( @nodes );
+	$self->{index_locations} = $args{index_locations};
 	$self->{source} = $content;
 	$self->{failures} = $lexer->failures();
 	$self->{effective_modifiers} =
 	    $tokenizer->__effective_modifiers();
+	if ( $args{location} ) {
+	    ARRAY_REF eq ref $args{location}
+		or croak q<Argument 'location' must be an array reference>;
+	    foreach my $inx ( 0 .. 3 ) {
+		$args{location}[$inx] =~ m/ [^0-9] /smx
+		    and croak "Argument 'location' element $inx must be an unsigned integer";
+	    }
+	    $self->{location} = $args{location};
+	}
 	return $self;
     }
 
@@ -409,7 +463,6 @@ any objects specified are removed from the cache.
 
 sub can_be_quantified { return; }
 
-
 =head2 capture_names
 
  foreach my $name ( $re->capture_names() ) {
@@ -523,7 +576,6 @@ sub extract_regexps {
     );
 }
 
-
 =head2 failures
 
  print "There were ", $re->failures(), " parse failures\n";
@@ -620,7 +672,7 @@ sub modifier_asserted {
 # This is a kluge for both determining whether the object asserts
 # modifiers (hence the 'ductype') and determining whether the given
 # modifier is actually asserted. The signature is the invocant and the
-# modifier name, which must not be undef. The return is a boolean.
+# modifier name, which must not be undef. The return is a Boolean.
 *__ducktype_modifier_asserted = \&modifier_asserted;
 
 # As of Perl 5.21.1 you can not leave off the type of a '?'-delimited
@@ -873,10 +925,24 @@ L<Regexp::Parser|Regexp::Parser>, which parses a bare regular expression
 navigation model. After a long hiatus, this module has been adopted, and
 is again supported.
 
+L<YAPE::Regex|YAPE::Regex>, which provides the parse tree, and has a
+mechanism to subclass the various element classes for customization. The
+most-recent release is 2011, but the CPAN testers results are still all
+green. Companion module L<YAPE::Regex::Explain|YAPE::Regex::Explain>
+says what the various pieces of a regex do, though constructs added in
+perl 5.10 and later are not supported. I have no idea how I missed this
+when I originally went looking for C<Regexp> parsers.
+
+L<PPR|PPR>, which recognizes Perl of all sorts, including regular
+expressions, but does not actually provide a parse of the recognized
+constructs.
+
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -884,7 +950,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2023 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
