@@ -1,5 +1,103 @@
 package PPIx::Regexp::Constant;
 
+# Yes, I know this is horrible style. But I need a separate package for
+# overloading to work, and I do *NOT* want stray files lying around if I
+# end up ditching this mess.
+package PPIx::Regexp::Constant::Inf;	## no critic (ProhibitMultiplePackages)
+
+use 5.006;
+
+use strict;
+use warnings;
+
+use Carp;
+use Scalar::Util qw{ refaddr };
+
+our $VERSION = '0.087';
+
+use overload
+    # Arithmetic
+    '+'		=> \&__preserve,
+    '-'		=> \&__subtract,
+    '*'		=> \&__preserve,
+    neg		=> \&__err_neg_inf,
+    # Comparison
+    '<=>'	=> \&__space_ship,
+    cmp		=> \&__cmp,
+    # Conversion
+    '""'	=> \&__stringify,
+    '0+'	=> \&__stringify,	# For looks_like_number
+    bool	=> \&__bool,
+    # Catch all
+    nomethod	=> \&__bug_unimplemented,
+    ;
+
+{
+    my $inf;
+
+    # Scheduled block because __pos_inf() can be called at compile time.
+    BEGIN {
+	$inf = bless( \( my $x = 1 ), __PACKAGE__ );
+    }
+
+    sub __pos_inf { return $inf }
+
+    sub __is_inf { return ref $_[0] && refaddr( $_[0] ) == refaddr( $inf ) }
+}
+
+sub __bool { return 1 }
+
+sub __bug_unimplemented {
+    confess "Bug - Operation '$_[3]' is unimplemented";
+}
+
+sub __cmp {
+    my ( $x, $y, $swap ) = @_;
+    $swap
+	and return "$y" cmp "$x";
+    return "$x" cmp "$y";
+}
+
+sub __err_nan {
+    croak 'NaN not supported';
+}
+
+sub __err_neg_inf {
+    croak 'Negative infinity not supported';
+}
+
+# Any operation that does not change the value
+sub __preserve { return $_[0] };
+
+sub __space_ship {
+    my ( undef, $y, $swap ) = @_;	# We don't need our invocant
+    # Infinity is equal to itself
+    __is_inf( $y )
+	and return 0;
+    # Any number is less than infinity
+    $swap
+	and return -1;
+    # Infinity is greater than any number
+    return 1;
+}
+
+sub __stringify {
+    return 'Inf';
+}
+
+sub __subtract {
+    my ( $x, $y, $swap ) = @_;
+    __is_inf( $y )
+	and __err_nan();	# Which croaks
+    $swap
+	and __err_neg_inf();	# Which croaks
+    return $x;
+}
+
+1;
+
+package PPIx::Regexp::Constant;	## no critic (ProhibitMultiplePackages)
+
 use strict;
 use warnings;
 
@@ -8,7 +106,7 @@ use base qw{ Exporter };
 # CAVEAT: do not include any other PPIx-Regexp modules in this one, or
 # you will end up with a circular dependency.
 
-our $VERSION = '0.073';
+our $VERSION = '0.085_04';
 
 our @EXPORT_OK = qw{
     ARRAY_REF
@@ -20,6 +118,7 @@ our @EXPORT_OK = qw{
     COOKIE_REGEX_SET
     FALSE
     HASH_REF
+    INFINITY
     LITERAL_LEFT_CURLY_ALLOWED
     LITERAL_LEFT_CURLY_REMOVED_PHASE_1
     LITERAL_LEFT_CURLY_REMOVED_PHASE_2
@@ -31,6 +130,7 @@ our @EXPORT_OK = qw{
     LOCATION_LOGICAL_FILE
     MINIMUM_PERL
     MODIFIER_GROUP_MATCH_SEMANTICS
+    MSG_LOOK_BEHIND_TOO_LONG
     MSG_PROHIBITED_BY_STRICT
     NODE_UNKNOWN
     RE_CAPTURE_NAME
@@ -41,6 +141,7 @@ our @EXPORT_OK = qw{
     TOKEN_LITERAL
     TOKEN_UNKNOWN
     TRUE
+    VARIABLE_LENGTH_LOOK_BEHIND_INTRODUCED
     @CARP_NOT
 };
 
@@ -121,6 +222,23 @@ use constant COOKIE_LOOKAROUND_ASSERTION	=> 'lookaround';
 use constant FALSE		=> 0;
 use constant TRUE		=> 1;
 
+# This hack is because it appears that Strawberry Perl evaluates 0 +
+# 'inf' as zero under Perl 5.12.3 and below. But the real problem is
+# from a pure portability standpoint I can not count on IEEE 754 being
+# in use. So if 0 + 'Inf' (documented in perldata) is zero or an error I
+# fall back to an object that mimics its behavior to the extent I think
+# I need.
+# NOTE that the only way I have to test the ::Inf object is to comment
+# out the eval{} code. This is ugly, but I can not think of anything
+# better.
+BEGIN {
+    local $@ = undef;
+    require constant;
+    constant->import( INFINITY =>
+	eval { 0 + 'Inf' } || 
+	PPIx::Regexp::Constant::Inf->__pos_inf() );
+}
+
 use constant ARRAY_REF		=> ref [];
 use constant CODE_REF		=> ref sub {};
 use constant HASH_REF		=> ref {};
@@ -156,6 +274,8 @@ use constant MINIMUM_PERL	=> '5.000';
 
 use constant MODIFIER_GROUP_MATCH_SEMANTICS => 'match_semantics';
 
+use constant MSG_LOOK_BEHIND_TOO_LONG	=>
+    'Lookbehind longer than 255 not implemented';
 use constant MSG_PROHIBITED_BY_STRICT	=>
     q<prohibited by "use re 'strict'">;
 
@@ -177,6 +297,8 @@ use constant SUFFICIENT_UTF8_SUPPORT_FOR_WEIRD_DELIMITERS => $] ge '5.008003';
 use constant TOKEN_LITERAL	=> 'PPIx::Regexp::Token::Literal';
 use constant TOKEN_UNKNOWN	=> 'PPIx::Regexp::Token::Unknown';
 
+use constant VARIABLE_LENGTH_LOOK_BEHIND_INTRODUCED	=> '5.029009';
+
 1;
 
 __END__
@@ -262,10 +384,25 @@ C<\Q> is encountered, and it persists until the next C<\E>.
 
 The name of the cookie used to control regular expression sets.
 
+=head2 FALSE
+
+A false value. The author makes no commitment what the exact value is,
+only that Boolean operations will see it as false.
+
 =head2 HASH_REF
 
 This is the result of C<ref {}>.
 
+=head2 INFINITY
+
+This is the IEEE 754 value of C<Inf> if that can be generated, or an
+opaque overloaded object if not. Because the object does not (and I
+think can not) implement the complete behavior of IEEE 754 C<Inf>, this
+manifest constant should only be used for stringification and numeric
+comparison. Be aware that the numification of the object has to be the
+same as its stringification to keep C<looks_like_number()> happy.
+B<Caveat coder>.
+
 =head2 LITERAL_LEFT_CURLY_ALLOWED
 
 The Perl version at which allowed unescaped literal left curly brackets
@@ -304,6 +441,12 @@ The name of the
 L<PPIx::Regexp::Token::Modifier|PPIx::Regexp::Token::Modifier> group
 used to control match semantics.
 
+=head2 MSG_LOOK_BEHIND_TOO_LONG
+
+An appropriate error message for an unknown entity created from a
+quantifier which would make a look-behind assertion too long. This is
+cribbed verbatim from the Perl error message.
+
 =head2 MSG_PROHIBITED_BY_STRICT
 
 An appropriate error message for an unknown entity created because
@@ -352,10 +495,23 @@ L<PPIx::Regexp::Token::Literal|PPIx::Regexp::Token::Literal>.
 The name of the class that represents the unknown token. That is,
 L<PPIx::Regexp::Token::Unknown|PPIx::Regexp::Token::Unknown>.
 
+=head2 TRUE
+
+A true value. The author makes no commitment what the exact value is,
+only that Boolean operations will see it as true.
+
+=head2 VARIABLE_LENGTH_LOOK_BEHIND_INTRODUCED
+
+The version in which variable-length look-behinds were introduced.
+Currently this is C<'5.029009'>, and implies the limited lookbehind
+introduced at or about that version.
+
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -363,7 +519,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2023 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
