@@ -54,7 +54,7 @@ use PPIx::Regexp::Constant qw{
     @CARP_NOT
 };
 
-our $VERSION = '0.078';
+our $VERSION = '0.087';
 
 =head2 accepts_perl
 
@@ -712,6 +712,27 @@ sub previous_token {
     }
 }
 
+=head2 raw_width
+
+ my ( $raw_min, $raw_max ) = $self->raw_width();
+
+This public method returns the minimum and maximum width matched by the
+element before taking into account such details as what the element
+actually is and how it is quantified. Either or both elements can be
+C<undef> if the width can not be determined, and the maximum can be
+C<Inf>.
+
+This method was added in version 0.085_01.
+
+=cut
+
+# This implementation is appropriate to a structural element -- i.e. it
+# returns C<( 0, 0 )>.
+
+sub raw_width {
+    return ( 0, 0 );
+}
+
 =head2 remove_insignificant
 
 This method returns a new object manufactured from the invocant, but
@@ -723,7 +744,7 @@ you will get back a deep clone, but without the insignificant elements.
 
 If you call this method on any other L<PPIx::Regexp|PPIx::Regexp> class
 you will get back either the invocant or nothing. This may change to a
-clone of the invocant or nothing if unforseen problems arise with
+clone of the invocant or nothing if unforeseen problems arise with
 returning the invocant, or if objects become mutable (unlikely, but not
 impossible.)
 
@@ -765,7 +786,7 @@ This method was added in version 0.051_01.
 sub requirements_for_perl {
     my ( $self ) = @_;
     my @req;
-    foreach my $r ( @{ $self->__structured_requirements_for_perl() || [] } ) {
+    foreach my $r ( $self->__perl_requirements() ) {
 	push @req, defined $r->{removed} ?
 	"$r->{introduced} <= \$] < $r->{removed}" :
 	"$r->{introduced} <= \$]";
@@ -932,56 +953,6 @@ sub statement {
     return $source->statement();
 }
 
-# NOTE: This method is to be used ONLY for requirements_for_perl(). I
-# _may_ eventually expose it, but at the moment I do not consider it
-# stable. The exposure would be
-# sub structured_requirements_for_perl {
-#     my ( $self ) = @_;
-#     return $self->__structured_requirements_for_perl();
-# }
-# The return ia a reference to an array of hashes. Each hash contains
-# key {introduced} (the version the element was introduced) and MAYBE
-# key {removed} (the version the element was removed). There may be more
-# than one such, and their ranges will not overlap.
-sub __structured_requirements_for_perl {
-    my ( $self, $rslt ) = @_;
-    $rslt ||= $self->__structured_requirements_for_any_perl();
-
-    my @merged;
-    foreach my $left ( $self->__perl_requirements() ) {
-	foreach my $right ( @{ $rslt } ) {
-	    my $min = max( $left->{introduced}, $right->{introduced} );
-	    my $max = defined $left->{removed} ?
-		defined $right->{removed} ?
-		    min( $left->{removed}, $right->{removed} ) :
-		    $left->{removed} :
-		$right->{removed};
-	    defined $max
-		and $max <= $min
-		and next;
-	    push @merged, {
-		introduced	=> $min,
-		removed		=> $max,
-	    };
-	}
-    }
-    @{ $rslt } = @merged;
-
-    return $rslt;
-}
-
-# NOTE: This method is to be used ONLY to initialize
-# __structured_requirements_for_perl(). It returns a structure that
-# matches any Perl.
-sub __structured_requirements_for_any_perl {
-    return [
-	{
-	    introduced	=> MINIMUM_PERL,
-	    removed	=> undef,
-	},
-    ];
-}
-
 =head2 tokens
 
 This method returns all tokens contained in the element.
@@ -1042,6 +1013,36 @@ sub whitespace {
     return;
 }
 
+=head2 width
+
+ my ( $min, $max ) = $self->width();
+
+This method returns the minimum and maximum number of characters this
+element can match.
+
+Either element can be C<undef> if it cannot be determined. For example,
+for C</$foo/> both elements will be C<undef>.  Recursions will return
+C<undef> because they can not be analyzed statically -- or at least I am
+not smart enough to do so. Back references B<may> return C<undef> if the
+referred-to group can not be uniquely determined.
+
+It is possible for C<$max> to be C<Inf>. For example, for C</x*/>
+C<$max> will be C<Inf>.
+
+Elements that do not actually match anything will return zeroes.
+
+B<Note:> This method was added because I wanted better detection of
+variable-length look-behinds. Both it and L<raw_width()|/raw_width>
+(above) should be considered somewhat experimental.
+
+This method was added in version 0.085_01.
+
+=cut
+
+sub width {
+    return ( 0, 0 );
+}
+
 =head2 nav
 
 This method returns navigation information from the top of the hierarchy
@@ -1139,8 +1140,7 @@ sub __error {
     my ( $self, $msg ) = @_;
     defined $msg
 	or $msg = 'Was ' . ref $self;
-    $self->{error} = $msg;
-    bless $self, TOKEN_UNKNOWN;
+    TOKEN_UNKNOWN->__PPIX_ELEM__rebless( $self, error => $msg );
     return 1;
 }
 
@@ -1165,13 +1165,14 @@ sub __PPIX_LEXER__record_capture_number {
 
 # Called by the lexer to rebless
 sub __PPIX_ELEM__rebless {
-    my ( $class, $self ) = @_;		# %arg unused
+    my ( $class, $self, %arg ) = @_;
     $self ||= {};
     bless $self, $class;
     delete $self->{error};
-    defined $self->{error}
-	and return 1;
-    delete $self->{error};
+    return $self->__PPIX_ELEM__post_reblessing( %arg );
+}
+
+sub __PPIX_ELEM__post_reblessing {
     return 0;
 }
 
@@ -1187,8 +1188,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
-mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -1196,7 +1198,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2021 by Thomas R. Wyant, III
+Copyright (C) 2009-2023 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
