@@ -37,16 +37,17 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-use Carp qw{ confess };
+use Carp ();
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
+use PPIx::Regexp::Util;
 
-our $VERSION = '0.069';
+our $VERSION = '0.087';
 
 sub __new {
     my ( $class, $content, %arg ) = @_;
 
     defined $arg{error}
-	or confess 'Programming error - error argument required';
+	or Carp::confess( 'Programming error - error argument required' );
 
     my $self = $class->SUPER::__new( $content, %arg )
 	or return;
@@ -60,7 +61,6 @@ sub __new {
     return $self;
 }
 
-
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
 
@@ -69,6 +69,15 @@ sub explain {
     return $self->{explanation};
 }
 
+=head2 is_matcher
+
+This method returns C<undef> because, since we could not identify the
+token, we have no idea whether it matches anything.
+
+=cut
+
+sub is_matcher { return undef; }	## no critic (ProhibitExplicitReturnUndef)
+
 =head2 ordinal
 
 This method returns the results of the ord built-in on the content
@@ -83,20 +92,12 @@ sub ordinal {
     return ord $self->content();
 }
 
-sub __PPIX_ELEM__rebless {
-    my ( $class, $self, %arg ) = @_;
-    my $rslt = $class->SUPER::__PPIX_ELEM__rebless( $self, %arg );
-    unless ( defined( $self->{error} = $arg{error} ) ) {
-	Carp::cluck( 'Making unknown token with no error message' );
-	$self->{error} = 'Unspecified error';
-	$rslt++;
-    }
-    $self->{explanation} = defined $arg{explanation} ?
-	$arg{explanation} :
-	$arg{error};
-    return $rslt;
+sub width {
+    return ( undef, undef );
 }
 
+*__PPIX_ELEM__post_reblessing = \&PPIx::Regexp::Util::__post_rebless_error;
+
 # Since the lexer does not count these on the way in (because it needs
 # the liberty to rebless them into a known class if it figures out what
 # is going on) we count them as failures at the finalization step.
@@ -111,7 +112,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -119,7 +122,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2023 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
